@@ -26,6 +26,7 @@ import re
 
 # These are installation specific values created when SIP was configured.
 _pkg_config = {
+    'android_abi':        '',
     'arch':               '',
     'default_bin_dir':    '/usr/pkg/bin',
     'default_mod_dir':    '/usr/pkg/lib/python3.7/site-packages',
@@ -35,15 +36,15 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/pkg/include/python3.7',
     'py_inc_dir':         '/usr/pkg/include/python3.7',
     'py_lib_dir':         '/usr/pkg/lib/python3.7/config',
-    'py_version':         0x030702,
+    'py_version':         0x03070e,
     'qt_framework':       0,
     'sip_bin':            '/usr/pkg/bin/sip3.7',
-    'sip_config_args':    '-b /usr/pkg/bin -d /usr/pkg/lib/python3.7/site-packages -e /usr/pkg/include/python3.7 -v /usr/pkg/share/sip3.7 CFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include/python3.7 CXXFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include/python3.7 INCDIR=/usr/pkg/include LIBDIR=/usr/pkg/lib CFLAGS_SHLIB=-fPIC CXXFLAGS_SHLIB=-fPIC LFLAGS_SHLIB=-shared LFLAGS=   -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib',
+    'sip_config_args':    '-b /usr/pkg/bin -d /usr/pkg/lib/python3.7/site-packages -e /usr/pkg/include/python3.7 -v /usr/pkg/share/sip3.7 CFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include/python3.7 CXXFLAGS=-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include/python3.7 INCDIR=/usr/pkg/include LIBDIR=/usr/pkg/lib CFLAGS_SHLIB=-fPIC CXXFLAGS_SHLIB=-fPIC LFLAGS_SHLIB=-shared LFLAGS= -Wl,-zrelro  -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib',
     'sip_inc_dir':        '/usr/pkg/include/python3.7',
     'sip_module_dir':     '/usr/pkg/lib/python3.7/site-packages',
     'sip_root_dir':       '/usr/pkg/lib/python3.7/site-packages',
-    'sip_version':        0x04130d,
-    'sip_version_str':    '4.19.13',
+    'sip_version':        0x041319,
+    'sip_version_str':    '4.19.25',
     'universal':          ''
 }
 
@@ -100,7 +101,7 @@ _default_macros = {
     'INCDIR':                   '/usr/pkg/include',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '   -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib',
+    'LFLAGS':                   ' -Wl,-zrelro  -L/usr/lib -Wl,-R/usr/lib -Wl,-R/usr/pkg/lib',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
